@@ -26,7 +26,6 @@
 #include "ephy-embed-shell.h"
 #include "ephy-history-types.h"
 #include "ephy-security-levels.h"
-#include "ephy-web-process-extension-proxy.h"
 
 G_BEGIN_DECLS
 
@@ -43,7 +42,8 @@ G_DECLARE_FINAL_TYPE (EphyWebView, ephy_web_view, EPHY, WEB_VIEW, WebKitWebView)
                                         "^data:.*$|" \
                                         "^file:.*$|" \
                                         "^inspector://.*$|" \
-                                        "^webkit://.*$" \
+                                        "^webkit://.*$|" \
+                                        "^ephy-resource://.*$" \
                                         ")"
 
 #define EPHY_WEB_VIEW_DOMAIN_REGEX "^localhost(\\.[^[:space:]]+)?(:\\d+)?(:[0-9]+)?(/.*)?$|" \
@@ -85,7 +85,7 @@ void                       ephy_web_view_load_request             (EphyWebView
 void                       ephy_web_view_load_url                 (EphyWebView               *view,
                                                                    const char                *url);
 gboolean                   ephy_web_view_is_loading               (EphyWebView               *view);
-gboolean                   ephy_web_view_load_failed              (EphyWebView               *view);
+gboolean                   ephy_web_view_get_load_failed          (EphyWebView               *view);
 GdkPixbuf *                ephy_web_view_get_icon                 (EphyWebView               *view);
 EphyWebViewDocumentType    ephy_web_view_get_document_type        (EphyWebView               *view);
 EphyWebViewNavigationFlags ephy_web_view_get_navigation_flags     (EphyWebView               *view);
@@ -147,7 +147,7 @@ char                      *ephy_web_view_get_web_app_title_finish (EphyWebView
 void                       ephy_web_view_set_visit_type           (EphyWebView *view, 
                                                                    EphyHistoryPageVisitType visit_type);
 EphyHistoryPageVisitType   ephy_web_view_get_visit_type           (EphyWebView *view);
-void                       ephy_web_view_popups_manager_reset     (EphyWebView               *view);
+
 void                       ephy_web_view_save                     (EphyWebView               *view,
                                                                    const char                *uri);
 void                       ephy_web_view_load_homepage            (EphyWebView               *view);
@@ -166,8 +166,6 @@ gboolean                   ephy_web_view_get_reader_mode_state    (EphyWebView
 
 gboolean                   ephy_web_view_is_in_auth_dialog        (EphyWebView               *view);
 
-EphyWebProcessExtensionProxy *ephy_web_view_get_web_process_extension_proxy  (EphyWebView               *view);
-
 void                       ephy_web_view_show_auth_form_save_request (EphyWebView                    *web_view,
                                                                       const char                     *origin,
                                                                       const char                     *username,
@@ -175,4 +173,6 @@ void                       ephy_web_view_show_auth_form_save_request (EphyWebVie
                                                                       gpointer                        response_data,
                                                                       GDestroyNotify                  response_destroy);
 
+gboolean                   ephy_web_view_in_pdf_viewer             (EphyWebView              *view);
+
 G_END_DECLS
