@@ -77,7 +77,7 @@ struct _EphyLocationEntry {
   guint progress_timeout;
   gdouble progress_fraction;
 
-  gulong dns_prefetch_handler;
+  guint dns_prefetch_handle_id;
 
   guint user_changed : 1;
   guint can_redo : 1;
@@ -374,10 +374,7 @@ ephy_location_entry_dispose (GObject *object)
 {
   EphyLocationEntry *entry = EPHY_LOCATION_ENTRY (object);
 
-  if (entry->progress_timeout) {
-    g_source_remove (entry->progress_timeout);
-    entry->progress_timeout = 0;
-  }
+  g_clear_handle_id (&entry->progress_timeout, g_source_remove);
 
   g_clear_object (&entry->css_provider);
 
@@ -900,6 +897,23 @@ position_func (DzlSuggestionEntry *self,
   area->width -= margin.left + margin.right;
 }
 
+static void
+update_reader_icon (EphyLocationEntry *entry)
+{
+  GtkIconTheme *theme;
+  const gchar *name;
+
+  theme = gtk_icon_theme_get_default ();
+
+  if (gtk_icon_theme_has_icon (theme, "view-reader-symbolic"))
+    name = "view-reader-symbolic";
+  else
+    name = "ephy-reader-mode-symbolic";
+
+  gtk_image_set_from_icon_name (GTK_IMAGE (entry->reader_mode),
+                                name, GTK_ICON_SIZE_MENU);
+}
+
 static void
 ephy_location_entry_construct_contents (EphyLocationEntry *entry)
 {
@@ -968,7 +982,7 @@ ephy_location_entry_construct_contents (EphyLocationEntry *entry)
   /* Reader Mode */
   entry->reader_mode_event_box = gtk_event_box_new ();
   gtk_widget_set_tooltip_text (entry->reader_mode_event_box, _("Toggle reader mode"));
-  entry->reader_mode = gtk_image_new_from_icon_name ("ephy-reader-mode-symbolic", GTK_ICON_SIZE_MENU);
+  entry->reader_mode = gtk_image_new ();
   gtk_widget_set_valign (entry->reader_mode, GTK_ALIGN_CENTER);
   gtk_widget_show (entry->reader_mode);
   gtk_container_add (GTK_CONTAINER (entry->reader_mode_event_box), entry->reader_mode);
@@ -977,6 +991,10 @@ ephy_location_entry_construct_contents (EphyLocationEntry *entry)
   context = gtk_widget_get_style_context (entry->reader_mode);
   gtk_style_context_add_class (context, "entry_icon");
 
+  update_reader_icon (entry);
+  g_signal_connect_object (gtk_settings_get_default (), "notify::gtk-icon-theme-name",
+                           G_CALLBACK (update_reader_icon), entry, G_CONNECT_SWAPPED);
+
   g_object_connect (entry->url_entry,
                     "signal::icon-press", G_CALLBACK (icon_button_icon_press_event_cb), entry,
                     "signal::populate-popup", G_CALLBACK (entry_populate_popup_cb), entry,
@@ -995,7 +1013,6 @@ ephy_location_entry_init (EphyLocationEntry *le)
   le->user_changed = FALSE;
   le->block_update = FALSE;
   le->saved_text = NULL;
-  le->dns_prefetch_handler = 0;
 
   ephy_location_entry_construct_contents (le);
 }
@@ -1022,14 +1039,17 @@ free_prefetch_helper (PrefetchHelper *helper)
 static gboolean
 do_dns_prefetch (PrefetchHelper *helper)
 {
+/* FIXME: https://bugs.webkit.org/show_bug.cgi?id=204703 */
+#if WEBKIT_CHECK_VERSION (2, 27, 4)
   EphyEmbedShell *shell = ephy_embed_shell_get_default ();
 
   if (helper->uri)
     webkit_web_context_prefetch_dns (ephy_embed_shell_get_web_context (shell), helper->uri->host);
+#endif
 
-  helper->entry->dns_prefetch_handler = 0;
+  helper->entry->dns_prefetch_handle_id = 0;
 
-  return FALSE;
+  return G_SOURCE_REMOVE;
 }
 
 /*
@@ -1057,16 +1077,14 @@ proxy_resolver_ready_cb (GObject      *object,
     return;
   }
 
-  if (helper->entry->dns_prefetch_handler)
-    g_source_remove (helper->entry->dns_prefetch_handler);
-
-  helper->entry->dns_prefetch_handler =
+  g_clear_handle_id (&helper->entry->dns_prefetch_handle_id, g_source_remove);
+  helper->entry->dns_prefetch_handle_id =
     g_timeout_add_full (G_PRIORITY_DEFAULT,
                         250,
                         (GSourceFunc)do_dns_prefetch,
                         helper,
                         (GDestroyNotify)free_prefetch_helper);
-  g_source_set_name_by_id (helper->entry->dns_prefetch_handler, "[epiphany] do_dns_prefetch");
+  g_source_set_name_by_id (helper->entry->dns_prefetch_handle_id, "[epiphany] do_dns_prefetch");
 }
 
 static void
@@ -1330,10 +1348,7 @@ progress_hide (gpointer user_data)
 
   gtk_entry_set_progress_fraction (GTK_ENTRY (entry->url_entry), 0);
 
-  if (entry->progress_timeout) {
-    g_source_remove (entry->progress_timeout);
-    entry->progress_timeout = 0;
-  }
+  g_clear_handle_id (&entry->progress_timeout, g_source_remove);
 
   return G_SOURCE_REMOVE;
 }
@@ -1374,10 +1389,7 @@ ephy_location_entry_set_progress (EphyLocationEntry *entry,
 {
   gdouble current_progress;
 
-  if (entry->progress_timeout) {
-    g_source_remove (entry->progress_timeout);
-    entry->progress_timeout = 0;
-  }
+  g_clear_handle_id (&entry->progress_timeout, g_source_remove);
 
   if (!loading) {
     /* Setting progress to 0 when it is already 0 can actually cause the
