@@ -123,7 +123,7 @@ load_changed_cb (WebKitWebView   *view,
                  WebKitLoadEvent  load_event,
                  EphySession     *session)
 {
-  if (ephy_web_view_load_failed (EPHY_WEB_VIEW (view)))
+  if (ephy_web_view_get_load_failed (EPHY_WEB_VIEW (view)))
     return;
 
   if (load_event == WEBKIT_LOAD_FINISHED)
@@ -516,13 +516,10 @@ ephy_session_close (EphySession *session)
 
   LOG ("ephy_session_close");
 
-  if (session->save_source_id) {
-    /* There's a save pending, cancel it and save the session now since
-     * after closing the session the saving is no longer allowed.
-     */
-    g_source_remove (session->save_source_id);
-    session->save_source_id = 0;
-  }
+  /* If there's a save pending, cancel it and save the session now since
+   * after closing the session the saving is no longer allowed.
+   */
+  g_clear_handle_id (&session->save_source_id, g_source_remove);
 
   if (session->closing)
     return;
@@ -1007,6 +1004,7 @@ ephy_session_save_idle_cb (EphySession *session)
 
   if (ephy_shell_get_n_windows (shell) == 0) {
     session_delete (session);
+    save_data_free (data);
     return G_SOURCE_REMOVE;
   }
 
@@ -1028,18 +1026,15 @@ ephy_session_save (EphySession *session)
 
   g_assert (EPHY_IS_SESSION (session));
 
-  if (session->save_source_id) {
+  if (session->save_source_id)
     return;
-  }
 
-  if (session->dont_save) {
+  if (session->dont_save)
     return;
-  }
 
   policy = g_settings_get_enum (EPHY_SETTINGS_MAIN, EPHY_PREFS_RESTORE_SESSION_POLICY);
-  if (policy == EPHY_PREFS_RESTORE_SESSION_POLICY_NEVER) {
+  if (policy == EPHY_PREFS_RESTORE_SESSION_POLICY_NEVER)
     return;
-  }
 
   session->save_source_id = g_timeout_add_seconds_full (G_PRIORITY_DEFAULT_IDLE, 1,
                                                         (GSourceFunc)ephy_session_save_idle_cb,
@@ -1080,7 +1075,6 @@ typedef struct {
   guint32 user_time;
 
   EphyWindow *window;
-  gulong destroy_id;
   gboolean is_first_window;
   gint active_tab;
 
@@ -1106,11 +1100,6 @@ session_parser_context_free (SessionParserContext *context)
 {
   g_object_unref (context->session);
 
-  if (context->window) {
-    /* This can only happen if the session state is malformed. */
-    g_signal_handler_disconnect (context->window, context->destroy_id);
-  }
-
   g_free (context);
 }
 
@@ -1122,13 +1111,7 @@ session_parse_window (SessionParserContext  *context,
   GdkRectangle geometry = { -1, -1, 0, 0 };
   guint i;
 
-  if (context->window) {
-    /* This should only happen if the session state is malformed. */
-    return;
-  }
-
   context->window = ephy_window_new ();
-  context->destroy_id = g_signal_connect (context->window, "destroy", G_CALLBACK (gtk_widget_destroyed), &context->window);
 
   for (i = 0; names[i]; i++) {
     gulong int_value;
@@ -1171,13 +1154,6 @@ session_parse_embed (SessionParserContext  *context,
   gboolean is_pin = FALSE;
   guint i;
 
-  if (!context->window) {
-    /* This can happen if the session is malformed, or if the window is
-     * destroyed before the session finishes loading.
-     */
-    return;
-  }
-
   notebook = ephy_window_get_notebook (context->window);
 
   for (i = 0; names[i]; i++) {
@@ -1307,13 +1283,6 @@ session_end_element (GMarkupParseContext  *ctx,
     GtkWidget *notebook;
     EphyEmbedShell *shell = ephy_embed_shell_get_default ();
 
-    if (!context->window) {
-      /* This can happen if the session is malformed, or if the window is
-       * destroyed before the session finishes loading.
-       */
-      return;
-    }
-
     notebook = ephy_window_get_notebook (context->window);
     gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), context->active_tab);
 
@@ -1327,7 +1296,6 @@ session_end_element (GMarkupParseContext  *ctx,
 
     ephy_embed_shell_restored_window (shell);
 
-    g_clear_signal_handler (&context->destroy_id, context->window);
     context->window = NULL;
     context->active_tab = 0;
     context->is_first_window = FALSE;
@@ -1771,9 +1739,3 @@ ephy_session_clear (EphySession *session)
 
   ephy_session_save (session);
 }
-
-gboolean
-ephy_session_is_closing (EphySession *session)
-{
-  return session->closing;
-}
