@@ -260,8 +260,8 @@ on_search_entry_changed (GtkSearchEntry      *entry,
 }
 
 static char *
-get_selected_item (EphyPasswordsDialog  *dialog,
-                   PasswordsDialogColumn column)
+get_selected_item (EphyPasswordsDialog   *dialog,
+                   PasswordsDialogColumn  column)
 {
   GtkTreeModel *model;
   GList *selected;
@@ -416,7 +416,7 @@ populate_model_cb (GList    *records,
     gtk_list_store_insert_with_values (GTK_LIST_STORE (dialog->liststore),
                                        &iter,
                                        -1,
-                                       COL_PASSWORDS_ORIGIN, ephy_password_record_get_hostname (record),
+                                       COL_PASSWORDS_ORIGIN, ephy_password_record_get_origin (record),
                                        COL_PASSWORDS_USER, ephy_password_record_get_username (record),
                                        COL_PASSWORDS_PASSWORD, ephy_password_record_get_password (record),
                                        COL_PASSWORDS_INVISIBLE, "●●●●●●●●",
@@ -435,7 +435,7 @@ populate_model (EphyPasswordsDialog *dialog)
 
   /* Ask for all password records. */
   ephy_password_manager_query (dialog->manager,
-                               NULL, NULL, NULL, NULL, NULL,
+                               NULL, NULL, NULL, NULL, NULL, NULL,
                                populate_model_cb, dialog);
 }
 
