@@ -722,8 +722,6 @@ save_web_application (PrefsDialog *dialog)
   gboolean changed = FALSE;
   const char *text;
 
-  dialog->webapp_save_id = 0;
-
   if (!dialog->webapp)
     return G_SOURCE_REMOVE;
 
@@ -760,9 +758,7 @@ prefs_dialog_save_web_application (PrefsDialog *dialog)
   if (!dialog->webapp)
     return;
 
-  if (dialog->webapp_save_id)
-    g_source_remove (dialog->webapp_save_id);
-
+  g_clear_handle_id (&dialog->webapp_save_id, g_source_remove);
   dialog->webapp_save_id = g_timeout_add_seconds (1, (GSourceFunc)save_web_application, dialog);
 }
 
@@ -1660,6 +1656,7 @@ prefs_dialog_response_cb (GtkWidget   *widget,
 {
   if (dialog->webapp_save_id) {
     g_source_remove (dialog->webapp_save_id);
+    dialog->webapp_save_id = 0;
     save_web_application (dialog);
   }
 
@@ -2023,9 +2020,9 @@ reader_font_style_get_name (HdyEnumValueObject *value,
 
   switch (hdy_enum_value_object_get_value (value)) {
     case EPHY_PREFS_READER_FONT_STYLE_SANS:
-      return g_strdup (N_("Sans"));
+      return g_strdup (_("Sans"));
     case EPHY_PREFS_READER_FONT_STYLE_SERIF:
-      return g_strdup (N_("Serif"));
+      return g_strdup (_("Serif"));
     default:
       return NULL;
   }
@@ -2069,9 +2066,9 @@ reader_color_scheme_get_name (HdyEnumValueObject *value,
 
   switch (hdy_enum_value_object_get_value (value)) {
     case EPHY_PREFS_READER_COLORS_LIGHT:
-      return g_strdup (N_("Light"));
+      return g_strdup (_("Light"));
     case EPHY_PREFS_READER_COLORS_DARK:
-      return g_strdup (N_("Dark"));
+      return g_strdup (_("Dark"));
     default:
       return NULL;
   }
